@@ -261,13 +261,22 @@ compressfile (fdp, name, asb, cratio)
   namelen = strlen (name);
   /* Hard link handling code will break if we do compression on the 
      file, so try to compress only if no links or hard link handling.
+     Note that if forceZflag==1 than also lflag==1 was set, so this
+     test will never return false.
 
      Also only try to compress if not already compressed,
-     or length is >= threshold, but always try if we force compression
+     or length is >= threshold, or <= maxsizetocompress, 
+     but always try if we force compression
   */
-  if ( (lflag || (asb->sb_nlink == 1)) &&
-       ((!matchcompext(name) && (asb->sb_size >= compthreshold))
-         || forceZflag)
+
+  if ( (lflag || (asb->sb_nlink == 1)) 
+       &&
+       ( ( !matchcompext(name)
+           && (asb->sb_size >= compthreshold) 
+           && ((maxsizetocompress==0) || (asb->sb_size <= maxsizetocompress))
+         )
+	 || forceZflag
+       )
      )
   {  
     /* make sure compress could put on the .Z */
@@ -340,7 +349,7 @@ compressfile (fdp, name, asb, cratio)
                     asb->sb_rdev &= ~RDEV_NOTCOMPR;
 
 		    if (cratio)
-		      *cratio = (asb2.sb_size * 100L) / asb->sb_size;
+		      *cratio = (int)((asb2.sb_size * 100.0) / asb->sb_size);
 		    asb->sb_size = asb2.sb_size;
 		    *fdp = MEMFD; 
 		  }
@@ -356,7 +365,7 @@ compressfile (fdp, name, asb, cratio)
 		      asb->sb_rdev &= ~RDEV_NOTCOMPR;
                        
 		      if (cratio)
-		        *cratio = (asb2.sb_size * 100L) / asb->sb_size;
+			*cratio = (int)((asb2.sb_size * 100.0) / asb->sb_size);
 		      asb->sb_size = asb2.sb_size;
 		      *fdp = compout;
 		    }
