@@ -90,12 +90,12 @@ nameaddfile(fname,not)
      int not;
 {
  FILE *infile;
- char pat[1001];
+ char pat[PATHSIZE+1];
 
  infile=fopen(fname,"r");
  if(infile==0) return 0;
 
- while(fgets(pat,1000,infile)!=NULL)
+ while(fgets(pat,PATHSIZE,infile)!=NULL)
    {
     /* remove \n */
      pat[strlen(pat)-1]='\0';
