@@ -1,5 +1,5 @@
-#define VERSION	"2.4.6"
-#define DATE	"25 Nov 1999"
+#define VERSION	"2.4.7"
+#define DATE	"9 Oct 2001"
 
 /*
  * Version 1.68		               1985	Mark Brukhartz
@@ -17,4 +17,5 @@
  * Version 2.4.4                21 Jun 1998     Koen Holtman
  * Version 2.4.5                28 Sep 1998     Koen Holtman
  * Version 2.4.6                25 Nov 1999     Koen Holtman
+ * Version 2.4.7                09 Oct 2001     Koen Holtman
  */
